@@ -1,6 +1,6 @@
 """A library for installing Python wheels."""
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 __all__ = ["install"]
 
-from ._core import install  # noqa
+from installer._core import install  # noqa
